==> haondt_athena-2.3.0.tar.gz: haondt_athena-2.3.0/tests/e2e/api/test_body.py <==
import subprocess, time, os, json
import pytest

@pytest.fixture(scope="module")
def setup_athena(tmp_path_factory):
    tmp_dir = tmp_path_factory.mktemp('test_tmp')
    subprocess.run(['athena', 'init', tmp_dir], capture_output=True, text=True)
    yield os.path.join(tmp_dir, 'athena')

API_HOST='flask-test-image:5000'

def test_form(setup_athena):
    athena_dir = setup_athena

    filename = 'test_form.py'
    code = f'''def run(athena):
    athena.client().post('http://{API_HOST}/api/echo', lambda r: r
        .body.form({{'foo': 'bar'}}))'''
    with open(os.path.join(athena_dir, filename), 'w') as f:
        f.write(code)

    result = subprocess.run(['athena', 'trace', filename], cwd=athena_dir, capture_output=True, text=True)

    assert result.returncode == 0
    trace = json.loads(result.stdout)[0]
    assert trace['success'] == True
    response = trace['athena_traces'][0]['response']
    response_body = json.loads(response['text'])

    assert response_body['headers']['Content-Type'] == 'application/x-www-form-urlencoded'
    assert response_body['form']['foo'] == ['bar']

def test_form_append(setup_athena):
    athena_dir = setup_athena

    filename = 'test_form_append.py'
    code = f'''def run(athena):
    athena.client().post('http://{API_HOST}/api/echo', lambda r: r
        .body.form({{'foo': 'bar'}})
        .body.form_append('foo', ['baz', 'qux']))'''
    with open(os.path.join(athena_dir, filename), 'w') as f:
        f.write(code)

    result = subprocess.run(['athena', 'trace', filename], cwd=athena_dir, capture_output=True, text=True)

    assert result.returncode == 0
    trace = json.loads(result.stdout)[0]
    print(trace)
    assert trace['success'] == True
    response = trace['athena_traces'][0]['response']
    response_body = json.loads(response['text'])

    assert response_body['headers']['Content-Type'] == 'application/x-www-form-urlencoded'
    assert response_body['form']['foo'] == ['bar', 'baz', 'qux']

==> haondt_athena-5.0.3.tar.gz: haondt_athena-5.0.3/tests/e2e/api/test_body.py <==
import subprocess, time, os, json
import pytest

@pytest.fixture(scope="module")
def setup_athena(tmp_path_factory):
    tmp_dir = tmp_path_factory.mktemp('test_tmp')
    subprocess.run(['athena', 'init', tmp_dir], capture_output=True, text=True)
    yield os.path.join(tmp_dir, 'athena')

API_HOST='flask-test-image:5000'

def test_form(setup_athena):
    athena_dir = setup_athena

    filename = 'test_form.py'
    code = f'''def run(athena):
    athena.client().post('http://{API_HOST}/api/echo', lambda r: r
        .body.form({{'foo': 'bar'}}))'''
    with open(os.path.join(athena_dir, filename), 'w') as f:
        f.write(code)

    result = subprocess.run(['athena', 'traces', '-p', filename], cwd=athena_dir, capture_output=True, text=True)

    assert result.returncode == 0
    trace = json.loads(result.stdout)
    assert trace['success'] == True
    response = trace['athena_traces'][0]['response']
    response_body = json.loads(response['text'])

    assert response_body['headers']['Content-Type'] == 'application/x-www-form-urlencoded'
    assert response_body['form']['foo'] == ['bar']

def test_form_append(setup_athena):
    athena_dir = setup_athena

    filename = 'test_form_append.py'
    code = f'''def run(athena):
    athena.client().post('http://{API_HOST}/api/echo', lambda r: r
        .body.form({{'foo': 'bar'}})
        .body.form_append('foo', ['baz', 'qux']))'''
    with open(os.path.join(athena_dir, filename), 'w') as f:
        f.write(code)

    result = subprocess.run(['athena', 'traces', '-p', filename], cwd=athena_dir, capture_output=True, text=True)

    assert result.returncode == 0
    trace = json.loads(result.stdout)
    print(trace)
    assert trace['success'] == True
    response = trace['athena_traces'][0]['response']
    response_body = json.loads(response['text'])

    assert response_body['headers']['Content-Type'] == 'application/x-www-form-urlencoded'
    assert response_body['form']['foo'] == ['bar', 'baz', 'qux']
